BoxxInterface class abstract

Platform storage contract shared by native and web implementations.

Implementers

Constructors

BoxxInterface({required String namespace, required EncryptionMode mode, required String? encryptionKey, required EncryptionMode legacyMode, required String? legacyEncryptionKey})

Properties

aes → EncryptAES
final
codec → StoredRecordCodec
final
encryptionKey String?
final
fernet → EncryptFernet
final
hashCode int
The hash code for this object.
no setterinherited
legacyEncryptionKey String?
final
legacyMode EncryptionMode
final
mode EncryptionMode
final
namespace String
final
onChange Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
delete(String key) Future<void>
dispose() → void
exists(String key) Future<bool>
get(String key) Future
getKeys() Future<List<String>>
getValues() Future<List>
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(String key) → void
Emits an in-process change. Web overrides this to broadcast across tabs.
notifyRemoteListeners(String key) → void
Emits a change received from another process or browser context.
put(String key, dynamic value) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited