BoxxHelper class

IndexedDB implementation used by Flutter web.

Inheritance

Constructors

BoxxHelper({required String namespace, required EncryptionMode mode, required String? encryptionKey, required EncryptionMode legacyMode, required String? legacyEncryptionKey})

Properties

aes → EncryptAES
finalinherited
codec → StoredRecordCodec
finalinherited
encryptionKey String?
finalinherited
fernet → EncryptFernet
finalinherited
hashCode int
The hash code for this object.
no setterinherited
legacyEncryptionKey String?
finalinherited
legacyMode EncryptionMode
finalinherited
mode EncryptionMode
finalinherited
namespace String
finalinherited
onChange Stream<String>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
override
delete(String key) Future<void>
override
dispose() → void
override
exists(String key) Future<bool>
override
get(String key) Future
override
getKeys() Future<List<String>>
override
getValues() Future<List>
override
initialize() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(String key) → void
Emits an in-process change. Web overrides this to broadcast across tabs.
override
notifyRemoteListeners(String key) → void
Emits a change received from another process or browser context.
inherited
put(String key, dynamic value) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited