BoxxFactory class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBoxxInterface({required String namespace, required EncryptionMode mode, required String? encryptionKey, required EncryptionMode legacyMode, required String? legacyEncryptionKey}) BoxxInterface
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

instance → const BoxxFactory