BoxxInterface class abstract

Blueprint for boxx platform classes, providing the structure that must be followed by boxx subclasses to maintain a consistent API. This ensures that developers using boxx have a predictable and standardized interface to work with

Implementers

Constructors

BoxxInterface({required EncryptionMode? mode, String? encryptionKey})

Properties

aes → EncryptAES
final
encryptionKey String?
final
fernet → EncryptFernet
final
hashCode int
The hash code for this object.
no setterinherited
mode EncryptionMode?
final
onChange Stream<String>
Stream of altered keys
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() Future<void>
Clear all data from local storage
delete(String key) Future<void>
Delete from local storage
dispose() → void
Close the stream controller
exists(String key) Future<bool>
Check if key exists in local storage
get(String key) Future
Get from local storage
getKeys() Future<List<String>>
Get all keys
getValues() Future<List>
Get all values
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners(String key) → void
Notify listeners that a key has changed
put(String key, dynamic value) Future<void>
Save to local storage
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited