BoxxHelper class
Boxx helper for web platform
- Inheritance
-
- Object
- BoxxInterface
- BoxxHelper
Constructors
- BoxxHelper({required EncryptionMode? mode, String? encryptionKey})
Properties
- aes → EncryptAES
-
finalinherited
- encryptionKey → String?
-
finalinherited
- fernet → EncryptFernet
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → EncryptionMode?
-
finalinherited
-
onChange
→ Stream<
String> -
Stream of altered keys
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → Future< void> -
Clear all data from local storage
override
-
delete(
String key) → Future< void> -
Delete from local storage
override
-
dispose(
) → void -
Close the stream controller
inherited
-
exists(
String key) → Future< bool> -
Check if key exists in local storage
override
-
get(
String key) → Future -
Get from local storage
override
-
getKeys(
) → Future< List< String> > -
Get all keys
override
-
getValues(
) → Future< List> -
Get all values
override
-
initialize(
) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
String key) → void -
Notify listeners that a key has changed
inherited
-
put(
String key, dynamic value) → Future< void> -
Save to local storage
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited